// Load the iris dataset
d3.csv("https://raw.githubusercontent.com/mwaskom/seaborn-data/master/iris.csv").then(data => {
  // Convert the numeric columns to numbers
  data.forEach(d => {
    d.sepal_length = +d.sepal_length;
    d.sepal_width = +d.sepal_width;
    d.petal_length = +d.petal_length;
    d.petal_width = +d.petal_width;
  });

  // Function to create the scatter plot
  function createScatterPlot(xAttr, yAttr) {
    // Set dimensions and margins
    const margin = { top: 20, right: 20, bottom: 30, left: 40 };
    const width = 600 - margin.left - margin.right;
    const height = 400 - margin.top - margin.bottom;

    // Create the SVG container
    const svg = d3.select("#scatterPlot")
      .append("svg")
      .attr("width", width + margin.left + margin.right)
      .attr("height", height + margin.top + margin.bottom)
      .append("g")
      .attr("transform", `translate(${margin.left},${margin.top})`);

    // Create scales for x and y axes
    const xScale = d3.scaleLinear()
      .domain(d3.extent(data, d => d[xAttr]))
      .range([0, width]);

    const yScale = d3.scaleLinear()
      .domain(d3.extent(data, d => d[yAttr]))
      .range([height, 0]);

    // Create x and y axes
    const xAxis = d3.axisBottom(xScale);
    const yAxis = d3.axisLeft(yScale);

    // Add x axis to the chart
    svg.append("g")
      .attr("transform", `translate(0, ${height})`)
      .call(xAxis);

    // Add y axis to the chart
    svg.append("g")
      .call(yAxis);

    // Create circles for the data points
    svg.selectAll("circle")
      .data(data)
      .enter()
      .append("circle")
      .attr("cx", d => xScale(d[xAttr]))
      .attr("cy", d => yScale(d[yAttr]))
      .attr("r", 5)
      .attr("fill", "steelblue")
      .attr("opacity", 0.7);

    // Add labels for x and y axes
    svg.append("text")
      .attr("x", width / 2)
      .attr("y", height + margin.bottom)
      .attr("text-anchor", "middle")
      .text(xAttr);

    svg.append("text")
      .attr("transform", "rotate(-90)")
      .attr("x", -height / 2)
      .attr("y", -margin.left)
      .attr("text-anchor", "middle")
      .text(yAttr);
  }

  // Call the createScatterPlot function with 'sepal_length' and 'sepal_width' attributes
  createScatterPlot('sepal_length', 'sepal_width');
});
